rusty_mos::consts::error

Enum KError

#[repr(i8)]
pub enum KError { Unspecified = 1, BadEnv = 2, Invalid = 3, NoMem = 4, NoSys = 5, NoFreeEnv = 6, IpcNotRecv = 7, PoolNotFound = 14, PoolDoubleBind = 15, PoolNotBind = 16, NoLock = 17, LockByOthers = 18, }
Error Codes Enum only for the Kernel

Variants



Unspecified = 1

Unspecified or unknown problem



BadEnv = 2

The environment does not exist or otherwise cannot be used in requestd action



Invalid = 3

The parameter is invalid



NoMem = 4

Run out of memory



NoSys = 5

Invalid syscall number



NoFreeEnv = 6

The environment maximum count exceeded



IpcNotRecv = 7

Attempt to send to env that is not recving



PoolNotFound = 14

Invalid memory pool id



PoolDoubleBind = 15

An env try to bind to a pool twice



PoolNotBind = 16

The env is not binded to the pool



NoLock = 17

Unlock a lock without being locked



LockByOthers = 18

Unlock a lock which was locked by another env